@@ -9,6 +9,7 @@
 #pragma once
 
 #include "duckdb/common/constants.hpp"
+#include "duckdb/common/vector.hpp"
 
 namespace duckdb {
 
@@ -17,6 +18,8 @@ enum class OptimizerType : uint32_t {
 	EXPRESSION_REWRITER,
 	FILTER_PULLUP,
 	FILTER_PUSHDOWN,
+	EMPTY_RESULT_PULLUP,
+	CTE_FILTER_PUSHER,
 	REGEX_RANGE,
 	IN_CLAUSE,
 	JOIN_ORDER,
@@ -27,14 +30,22 @@ enum class OptimizerType : uint32_t {
 	COMMON_SUBEXPRESSIONS,
 	COMMON_AGGREGATE,
 	COLUMN_LIFETIME,
+	BUILD_SIDE_PROBE_SIDE,
+	LIMIT_PUSHDOWN,
 	TOP_N,
 	COMPRESSED_MATERIALIZATION,
 	DUPLICATE_GROUPS,
 	REORDER_FILTER,
-	EXTENSION
+	SAMPLING_PUSHDOWN,
+	JOIN_FILTER_PUSHDOWN,
+	EXTENSION,
+	MATERIALIZED_CTE,
+	SUM_REWRITER,
+	LATE_MATERIALIZATION
 };
 
 string OptimizerTypeToString(OptimizerType type);
 OptimizerType OptimizerTypeFromString(const string &str);
+vector<string> ListAllOptimizers();
 
 } // namespace duckdb
