@@ -13,6 +13,7 @@
 #include "duckdb/planner/tableref/bound_basetableref.hpp"
 #include "duckdb/common/unordered_map.hpp"
 #include "duckdb/common/optional_ptr.hpp"
+#include "duckdb/catalog/dependency_list.hpp"
 
 namespace duckdb {
 class Serializer;
@@ -37,16 +38,13 @@ public:
 	explicit VacuumInfo(VacuumOptions options);
 
 	const VacuumOptions options;
-
-public:
+	vector<string> columns;
 	bool has_table;
 	unique_ptr<TableRef> ref;
-	optional_ptr<TableCatalogEntry> table;
-	unordered_map<idx_t, idx_t> column_id_map;
-	vector<string> columns;
 
 public:
 	unique_ptr<VacuumInfo> Copy();
+	string ToString() const;
 
 	void Serialize(Serializer &serializer) const override;
 	static unique_ptr<ParseInfo> Deserialize(Deserializer &deserializer);
