@@ -14,22 +14,23 @@
 namespace duckdb {
 class TableCatalogEntry;
 
-//! The ALTER binder is responsible for binding an expression within alter statements
+//! The AlterBinder binds expressions in ALTER statements.
 class AlterBinder : public ExpressionBinder {
 public:
 	AlterBinder(Binder &binder, ClientContext &context, TableCatalogEntry &table, vector<LogicalIndex> &bound_columns,
 	            LogicalType target_type);
 
-	TableCatalogEntry &table;
-	vector<LogicalIndex> &bound_columns;
-
 protected:
+	BindResult BindLambdaReference(LambdaRefExpression &expr, idx_t depth);
+	BindResult BindColumnReference(ColumnRefExpression &expr, idx_t depth);
 	BindResult BindExpression(unique_ptr<ParsedExpression> &expr_ptr, idx_t depth,
 	                          bool root_expression = false) override;
 
-	BindResult BindColumn(ColumnRefExpression &expr);
-
 	string UnsupportedAggregateMessage() override;
+
+private:
+	TableCatalogEntry &table;
+	vector<LogicalIndex> &bound_columns;
 };
 
 } // namespace duckdb
